@@ -18,10 +18,10 @@
 
 
 def determine_project_name_from_git_url(git_url):
-    start_index = git_url.rfind('/') + 1
+    start_index = git_url.rfind('/') + len('/')
 
     if git_url.endswith('.git'):
-        end_index = len(git_url) - 4
+        end_index = len(git_url) - len('.git')
     else:
         end_index = len(git_url)
 
